---
title: <span class="badge builder"></span> Placement
---
# <span class="badge builder"></span> Placement

## Constructor

```python
Placement()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> canvas.Placement
```

### <span class="badge object-method"></span> bottom

```python
def bottom(bottom: float) -> typing.Self
```

### <span class="badge object-method"></span> height

```python
def height(height: float) -> typing.Self
```

### <span class="badge object-method"></span> left

```python
def left(left: float) -> typing.Self
```

### <span class="badge object-method"></span> right

```python
def right(right: float) -> typing.Self
```

### <span class="badge object-method"></span> top

```python
def top(top: float) -> typing.Self
```

### <span class="badge object-method"></span> width

```python
def width(width: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Placement](./object-Placement.md)
